==> haskell-yesod-form-1.6.6-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.6.6
id: yesod-form-1.6.6-15eLsoQvPfRpACOVzKawT
key: yesod-form-1.6.6-15eLsoQvPfRpACOVzKawT
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
abi: 1f304d218b2372f62a472bc7a14b7a1c
exposed: True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Spanish
    Yesod.Form.I18n.Swedish Yesod.Form.Input Yesod.Form.Jquery
    Yesod.Form.MassInput Yesod.Form.Nic Yesod.Form.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-form-1.6.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-form-1.6.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-form-1.6.6
hs-libraries: HSyesod-form-1.6.6-15eLsoQvPfRpACOVzKawT
depends:
    aeson-1.4.4.0-HZF4dQ7ymfT471uy0aBwyJ
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.1-Icge9VdFJKdIYmonGkJUKg
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q
    byteable-0.1.1-9guyEXUUK503mzSnI32g2S bytestring-0.10.8.2
    containers-0.6.0.1 data-default-0.7.1.1-1LPfbbioWzl7RPD13iVYcW
    email-validate-2.3.2.11-25dWWI6VGo6Hpd1OWzgTwT
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    persistent-2.10.0-5TmQDzXKJWKAJCRYTAW1bm
    resourcet-1.2.2-8hEDHRutAsl8XBsaHNUdIq
    shakespeare-2.0.20-DTzhm8310JcFJnWEKqapaT text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 wai-3.2.2.1-CQ54CFlyR3DJGjuiF7FXOI
    xss-sanitize-0.3.6-7xRiZP57p8M9xfo0wgyZiQ
    yesod-core-1.6.14-LDhycdhz7aB4O53Gk9ahIP
    yesod-persistent-1.6.0.2-CGtfbr0LU2acmqJJPetG9
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-form-1.6.6-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.6.6
id: yesod-form-1.6.6-IX1MkdCZsvNHGWq4jw7p7F
key: yesod-form-1.6.6-IX1MkdCZsvNHGWq4jw7p7F
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
abi: aa46bf80b6639726924781b4d1ec0340
exposed: True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Spanish
    Yesod.Form.I18n.Swedish Yesod.Form.Input Yesod.Form.Jquery
    Yesod.Form.MassInput Yesod.Form.Nic Yesod.Form.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-form-1.6.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-form-1.6.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-form-1.6.6
hs-libraries: HSyesod-form-1.6.6-IX1MkdCZsvNHGWq4jw7p7F
depends:
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.1-Icge9VdFJKdIYmonGkJUKg
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q
    byteable-0.1.1-9guyEXUUK503mzSnI32g2S bytestring-0.10.8.2
    containers-0.6.0.1 data-default-0.7.1.1-FxanJFkeYAJQ1iDuwiDPz
    email-validate-2.3.2.11-25dWWI6VGo6Hpd1OWzgTwT
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    persistent-2.10.0-F4CPpPaYOvl8cb6reliVex
    resourcet-1.2.2-8hEDHRutAsl8XBsaHNUdIq
    shakespeare-2.0.20-Cful4WDaZNYHiOOgCEfuhl text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 wai-3.2.2.1-CQ54CFlyR3DJGjuiF7FXOI
    xss-sanitize-0.3.6-7xRiZP57p8M9xfo0wgyZiQ
    yesod-core-1.6.14-Bz31HlCM7Qc9sRGPGsG4xj
    yesod-persistent-1.6.0.2-FO3rOL1IsNdBCAFUpdTCl9
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
